@@ -1,7 +1,7 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2017, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 /* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 
@@ -15,7 +15,7 @@ const Me = ExtensionUtils.getCurrentExtension();
 const Indicator = Me.imports.indicator;
 
 function init(extension) {
-    let metadata = extension.metadata;
+    const metadata = extension.metadata;
     Gettext.bindtextdomain(metadata.gettext_package, metadata.localedir);
 }
 
